@@ -1,31 +1,23 @@
-#!perl
-# ABSTRACT: Client for Azure Blob Storage
-
+package Net::Azure::StorageClient;
 use strict;
 use warnings;
-use v5.10;
-
-package Net::Azure::StorageClient;
-$Net::Azure::StorageClient::VERSION = '0.5_03'; # TRIAL
-
-$Net::Azure::StorageClient::VERSION = '0.503';
+{
+  $Net::Azure::StorageClient::VERSION = '0.2';
+}
 use LWP::UserAgent;
-use HTTP::Date qw/ time2str /;
+use HTTP::Date;
 use URI::QueryParam;
 use MIME::Base64;
 use Digest::SHA qw( hmac_sha256_base64 );
-use Digest::MD5 qw( md5_base64 );
-
-use namespace::clean;
 
 sub new {
     my $class = shift;
     my %args  = @_;
     my $type = $args{ type };
-    if ( $type && $type =~ m/^Blob$/i ) { # |Table|Queue
+    if ( $type && $type =~ /^Blob$/i ) { # |Table|Queue
         $type = ucfirst( $type );
-        $class .= '::' . $type;
-        eval "require $class;"; ## no critic (ProhibitStringyEval)
+        $class .= "::" . $type;
+        eval "use $class;";
         # die "Unsupported StorageClient $class: $@" if $@;
     }
     my $obj = bless {}, $class;
@@ -34,22 +26,25 @@ sub new {
 }
 
 sub init {
-    my ( $self, %args ) = @_;
-    $self->{ account_name } = $args{ account_name };
-    $self->{ primary_access_key } = $args{ primary_access_key };
-    $self->{ api_version } = $args{ api_version } || '2012-02-12';
-    $self->{ protocol } = $args{ protocol } || 'https';
-    return $self;
+    my $storageClient = shift;
+    my %args = @_;
+    $storageClient->{ account_name } = $args{ account_name };
+    $storageClient->{ primary_access_key } = $args{ primary_access_key };
+    $storageClient->{ api_version } = $args{ api_version } || '2012-02-12';
+    $storageClient->{ protocol } = $args{ protocol } || 'https';
+    return $storageClient;
 }
 
 sub sign {
-    my ( $self, $req, $params ) = @_;
-    my $key = $self->{ primary_access_key };
-    my $api_version = $self->{ api_version };
+    my $storageClient = shift;
+    my ( $req, $params ) = @_;
+    my $key = $storageClient->{ primary_access_key };
+    my $api_version = $storageClient->{ api_version };
     $req->header( 'x-ms-version', $api_version );
-    $req->header( 'x-ms-date', time2str() );
+    $req->header( 'x-ms-date', HTTP::Date::time2str() );
     if ( my $data = $params->{ body } ) {
-        $req->header( 'Content-MD5', md5_base64( $data ) . '==' );
+        require Digest::MD5;
+        $req->header( 'Content-MD5', Digest::MD5::md5_base64( $data ) . '==' );
         # $req->header( 'If-None-Match', '*' );
     }
     if ( $params && ( my $headers = $params->{ headers } ) ) {
@@ -60,7 +55,7 @@ sub sign {
     my $canonicalized_headers = join '', map { lc( $_ ) . ':' .
        $req->header( $_ ) . "\n" } sort grep { /^x-ms/ } keys %{ $req->headers };
     my $account = $req->uri->authority;
-    $account =~ s/^(\w+).*$/$1/;
+    $account =~ s/^([^.]*).*$/$1/;
     my $path = $req->uri->path;
     my $canonicalized_resource = "/${account}${path}";
     $canonicalized_resource .= join '', map { "\n" . lc( $_ ) . ':' .
@@ -92,20 +87,17 @@ sub sign {
     return $req;
 }
 
-# scope $ua
-{
-my $ua = LWP::UserAgent->new;
-
 sub request {
-    my ( $self, $method, $url, $params ) = @_;
+    my $storageClient = shift;
+    my ( $method, $url, $params ) = @_;
     $url = '' unless ( $url );
     if ( $url !~ m!^https{0,1}://! ) {
         if ( $url !~ m !^/! ) {
             $url = '/' . $url;
         }
-        my $type = $self->{ type };
-        my $account = $self->{ account_name };
-        my $protocol = $self->{ protocol };
+        my $type = $storageClient->{ type };
+        my $account = $storageClient->{ account_name };
+        my $protocol = $storageClient->{ protocol };
         $url = "${protocol}://${account}.${type}.core.windows.net${url}";
     }
     my $body;
@@ -113,42 +105,42 @@ sub request {
         $body = $params->{ body };
     }
     $method = 'GET' unless $method;
-    my $req = HTTP::Request->new( $method => $url );
+    my $req = new HTTP::Request( $method => $url );
     $req->content_length( length( $body ) ) if defined $body;
-    $req = $self->sign( $req, $params );
+    $req = $storageClient->sign( $req, $params );
     $req->content( $body ) if defined $body;
+    my $ua = LWP::UserAgent->new;
     return $ua->request( $req );
 }
 
-} # scope $ua
-
 sub get {
-    my $self = shift;
-    $self->request( 'GET', @_ );
+    my $storageClient = shift;
+    $storageClient->request( 'GET', @_ );
 }
 
 sub head {
-    my $self = shift;
-    $self->request( 'HEAD', @_ );
+    my $storageClient = shift;
+    $storageClient->request( 'HEAD', @_ );
 }
 
 sub put {
-    my $self = shift;
-    $self->request( 'PUT', @_ );
+    my $storageClient = shift;
+    $storageClient->request( 'PUT', @_ );
 }
 
 sub delete {
-    my $self = shift;
-    $self->request( 'DELETE', @_ );
+    my $storageClient = shift;
+    $storageClient->request( 'DELETE', @_ );
 }
 
 sub post {
-    my $self = shift;
-    $self->request( 'POST', @_ );
+    my $storageClient = shift;
+    $storageClient->request( 'POST', @_ );
 }
 
 sub _signed_identifier {
-    my ( $self, $length ) = @_;
+    my $storageClient = shift;
+    my $length = shift;
     my @char = () ;
     push @char, ( 'a' .. 'z' );
     push @char, ( 'A' .. 'Z' );
@@ -161,15 +153,16 @@ sub _signed_identifier {
 }
 
 sub _adjust_path {
-    my ( $self, $path ) = @_;
+    my $storageClient = shift;
+    my $path = shift;
     $path =~ s!^/!!;
-    if ( my $type = $self->{ type } ) {
+    if ( my $type = $storageClient->{ type } ) {
         my $arg;
         if ( $type eq 'blob' ) {
             $arg = 'container_name'
         }
         # table, queue...
-        if ( $arg && ( my $root = $self->{ $arg } ) ) {
+        if ( $arg && ( my $root = $storageClient->{ $arg } ) ) {
             $path = $root . '/' . $path;
         }
     }
@@ -180,17 +173,9 @@ sub _adjust_path {
 
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-Net::Azure::StorageClient - Client for Azure Blob Storage
-
-=head1 VERSION
-
-version 0.5_03
+Net::Azure::StorageClient - Windows Azure Storage Client
 
 =head1 SYNOPSIS
 
@@ -201,10 +186,6 @@ version 0.5_03
                                     [ protocol => 'https', ]
                                     [ api_version => '2012-02-12', ] );
 
-=head1 NAME
-
-Net::Azure::StorageClient - Windows Azure Storage Client
-
 =head1 METHODS
 
 =head2 sign
@@ -212,7 +193,7 @@ Net::Azure::StorageClient - Windows Azure Storage Client
 Specifying the authorization header to HTTP::Request object.
 http://msdn.microsoft.com/en-us/library/dd179428.aspx
 
-    my $req = HTTP::Request->new( 'GET', $url );
+    my $req = new HTTP::Request( 'GET', $url );
     $req = $StorageClient->sign( $req, $params );
 
 =head2 request
@@ -229,7 +210,7 @@ Specifying the authorization header and send request.
     my $res = $StorageClient->request( 'GET', $url );
 
     # Request with custom http headers and request body. Send POST request.
-    my $params = {
+    my $params = { 
                    headers => { 'x-ms-foo' => 'bar', },
                    body => $request_body,
                  };
@@ -261,35 +242,13 @@ Specifying the authorization header and send 'POST' request.
 
 Junnama Noda <junnama@alfasado.jp>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-This software is copyright (c) 2020 by Junnama Noda.
+Copyright (C) 2013, Junnama Noda.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+=head1 LICENSE
 
-=head1 CONTRIBUTORS
+This program is free software;
+you can redistribute it and modify it under the same terms as Perl itself.
 
-=for stopwords Alexandr Ciornii Dean Hamstead ksasakims paulbort
-
-=over 4
-
-=item *
-
-Alexandr Ciornii <alexchorny@gmail.com>
-
-=item *
-
-Dean Hamstead <djzort@cpan.org>
-
-=item *
-
-ksasakims <gitsasa@outlook.com>
-
-=item *
-
-paulbort <paulbort@gmail.com>
-
-=back
-
-=cut
+=cut
\ No newline at end of file
