@@ -1,14 +1,10 @@
-#!perl
-# ABSTRACT: MIME related functions for Azure Blob Storage client
-
+package Net::Azure::StorageClient::MIMEType;
 use strict;
 use warnings;
-use v5.10;
+{
+  $Net::Azure::StorageClient::MIMEType = '0.1';
+}
 
-package Net::Azure::StorageClient::MIMEType;
-$Net::Azure::StorageClient::MIMEType::VERSION = '0.5_03'; # TRIAL
-
-$Net::Azure::StorageClient::MIMEType::VERSION = '0.503';
 sub new {
     my $class = shift;
     my $obj = bless {}, $class;
@@ -16,14 +12,17 @@ sub new {
 }
 
 sub init {
-    my ($obj, %args) = @_;
+    my $obj = shift;
+    my %args = @_;
     $obj->{ default } = $args{ default } || 'application/octet-stream';
     return $obj;
 }
 
 sub get_mimetype {
-    my ($self, $filename, $default) = @_;
-    if ( ref $self ne 'Azure::StorageClient::MIMEType' ) {
+    my $self = shift;
+    my $filename = shift;
+    my $default = shift;
+    if ( ( ref $self ) ne 'Azure::StorageClient::MIMEType' ) {
         $default = $filename;
         $filename = $self;
     }
@@ -117,45 +116,19 @@ sub get_mimetype {
         'xlsx'   => 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
         'json'   => 'application/json',
     };
-    if ( $filename =~ m/\.([^.]+)\z/ ) {
+    if ( $filename =~ /\.([^.]+)\z/ ) {
         my $extension = lc( $1 );
         if ( $extension && $mime_types->{ $extension } ) {
             return $mime_types->{ $extension };
         }
     }
     if (! $default ) {
-        if ( ref $self eq 'Azure::StorageClient::MIMEType' ) {
+        if ( ( ref $self ) eq 'Azure::StorageClient::MIMEType' ) {
             $default = $self->{ default };
         }
     }
-    return $default || 'application/octet-stream';
+    $default = 'application/octet-stream' unless $default;
+    return $default;
 }
 
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Net::Azure::StorageClient::MIMEType - MIME related functions for Azure Blob Storage client
-
-=head1 VERSION
-
-version 0.5_03
-
-=head1 AUTHOR
-
-Junnama Noda <junnama@alfasado.jp>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Junnama Noda.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
+1;
\ No newline at end of file
